@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/context.c,v 1.55.2.1 2012/05/25 12:13:24 jfilipov Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/context.c,v 1.62 2012/08/08 10:21:03 mvocu Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -212,6 +212,8 @@ void edg_wll_FreeContext(edg_wll_Context ctx)
 	
 	if (ctx->authz_policy_file) free(ctx->authz_policy_file);
 
+	if (ctx->html_header_file) free(ctx->html_header_file);
+
 	edg_wll_FreeParams(ctx);
 
 	free(ctx);
@@ -346,6 +348,11 @@ static const char* const srcNames[] = {
 	"LBServer",
 	"CREAMInterface",
 	"CREAMExecutor",
+	"PBSClient",
+	"PBSServer",
+	"PBSMomSuperior",
+	"PBSMom",
+	"PBSScheduler"
 };
 
 edg_wll_Source edg_wll_StringToSource(const char *name)
@@ -414,7 +421,14 @@ char *edg_wll_GetSequenceCode(const edg_wll_Context ctx)
 					c[EDG_WLL_SOURCE_LB_SERVER]);
 			break;
 		case EDG_WLL_SEQ_PBS:
-			ret = strdup(ctx->p_seqcode.pbs);
+			c = &ctx->p_seqcode.c[0];
+			asprintf(&ret, EDG_WLL_SEQ_PBS_FORMAT_PRINTF,
+				 c[EDG_WLL_SOURCE_PBS_CLIENT],
+				 c[EDG_WLL_SOURCE_PBS_SERVER],
+				 c[EDG_WLL_SOURCE_PBS_SCHEDULER],
+				 c[EDG_WLL_SOURCE_PBS_SMOM],
+				 c[EDG_WLL_SOURCE_PBS_MOM]);
+			/* ret = strdup(ctx->p_seqcode.pbs); */
 			break;
 		case EDG_WLL_SEQ_CONDOR:
 			ret = strdup(ctx->p_seqcode.condor);
@@ -476,7 +490,7 @@ int edg_wll_SetSequenceCode(edg_wll_Context ctx,
 
 			if (seq_type == EDG_WLL_SEQ_DUPLICATE) {
 				if (ctx->p_source <= EDG_WLL_SOURCE_NONE || 
-						ctx->p_source >= EDG_WLL_SOURCE__LAST) 
+						ctx->p_source >= EDG_WLL_SOURCE__LAST)
 				{
 					return edg_wll_SetError(ctx,EINVAL,
 						"edg_wll_SetSequenceCode(): context param: source missing");
@@ -485,10 +499,27 @@ int edg_wll_SetSequenceCode(edg_wll_Context ctx,
 			}
 			break;
 		case EDG_WLL_SEQ_PBS:
+			/* original version
 			if (!seqcode_str) 
 				memset(&ctx->p_seqcode.pbs, 0, sizeof ctx->p_seqcode.pbs);
 			else
 				strncpy(ctx->p_seqcode.pbs, seqcode_str, sizeof(ctx->p_seqcode.pbs));
+			*/
+			if (!seqcode_str) {
+				memset(&ctx->p_seqcode.c, 0, sizeof(ctx->p_seqcode.c));
+				return 0;
+			}
+			c = ctx->p_seqcode.c;
+			res = sscanf(seqcode_str, EDG_WLL_SEQ_PBS_FORMAT_SCANF,
+				     &c[EDG_WLL_SOURCE_PBS_CLIENT],
+				     &c[EDG_WLL_SOURCE_PBS_SERVER],
+				     &c[EDG_WLL_SOURCE_PBS_SCHEDULER],
+				     &c[EDG_WLL_SOURCE_PBS_SMOM],
+				     &c[EDG_WLL_SOURCE_PBS_MOM]);
+			if(res != EDG_WLL_SEQ_PBS_FORMAT_NUMBER) {
+				return edg_wll_SetError(ctx, EINVAL,
+					"edg_wll_SetSequenceCode(): syntax error in sequence code");
+			}
 			break;
 		case EDG_WLL_SEQ_CONDOR:
 			if (!seqcode_str) 
@@ -511,6 +542,8 @@ int edg_wll_IncSequenceCode(edg_wll_Context ctx)
 	switch (ctx->p_seqcode.type) {
 		case EDG_WLL_SEQ_CREAM:
 			/* fall through */
+		case EDG_WLL_SEQ_PBS:
+			/* fall through */
 		case EDG_WLL_SEQ_DUPLICATE:
 			/* fall through */
 		case EDG_WLL_SEQ_NORMAL:
@@ -523,9 +556,6 @@ int edg_wll_IncSequenceCode(edg_wll_Context ctx)
 
 			ctx->p_seqcode.c[ctx->p_source]++;
 			break;
-		case EDG_WLL_SEQ_PBS:
-			/* no action */
-			break;
 		default:
 			break;
 	}
