@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/xml_conversions.c,v 1.24 2012/01/24 14:26:59 valtri Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.common/src/xml_conversions.c,v 1.26 2012/08/08 15:48:40 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -28,6 +28,7 @@ limitations under the License.
 #include "jobstat.h"
 
 
+extern char *edg_wll_TagListToString(edg_wll_TagValue *);
 
 static const struct timeval null_timeval = {0,0};
 
@@ -448,7 +449,17 @@ void edg_wll_add_intlist_to_XMLBody(char **body, const int *toAdd, const char *t
 }
 
 
-void edg_wll_add_taglist_to_XMLBody(char **body,  const edg_wll_TagValue *toAdd, const char *tag,  const char *subTag, const char *subTag2, const char *indent, const  char *null)
+void edg_wll_add_taglist_to_XMLBody(char **body, const edg_wll_TagValue *toAdd, const char *tag, const edg_wll_TagValue *null)
+{
+	char *s_taglist;
+
+	s_taglist = edg_wll_TagListToString(toAdd);
+	edg_wll_add_string_to_XMLBody(body, s_taglist, tag, NULL);
+	free(s_taglist);
+}
+
+
+void edg_wll_add_usertag_to_XMLBody(char **body,  const edg_wll_TagValue *toAdd, const char *tag,  const char *subTag, const char *subTag2, const char *indent, const  char *null)
 {
         char *pomA, *pomB, *newBody;
         char **list = NULL;
@@ -627,6 +638,22 @@ edg_wll_JobStatCode edg_wll_from_string_to_edg_wll_JobStatCode(edg_wll_XML_ctx *
 
 
 
+enum edg_wll_StatJobtype edg_wll_from_string_to_edg_wll_StatJobtype(edg_wll_XML_ctx *XMLCtx)
+{
+        enum edg_wll_StatJobtype out = -1;
+        char *s;
+
+        s = glite_lbu_UnescapeXML((const char *) XMLCtx->char_buf);
+        if (s) {
+           out = edg_wll_JobtypeStrToCode(s);
+           free(s);
+        }
+        edg_wll_freeBuf(XMLCtx); 
+
+        return(out);
+}
+
+
 
 /* XMLCtx->eventsOutGlobal[XMLCtx->position].jobClear.clearReason = 
 	edg_wll_from_string_to_int(XMLCtx); 				*/
@@ -746,6 +773,17 @@ void *edg_wll_from_string_to_cclassad(edg_wll_XML_ctx *XMLCtx)
 	return (NULL);
 }
 
+edg_wll_TagValue *edg_wll_from_string_to_taglist(edg_wll_XML_ctx *XMLCtx)
+{
+	char *s, *out = NULL;
+
+	s = glite_lbu_UnescapeXML((const char*) XMLCtx->char_buf);
+	if(s) {
+		edg_wll_TagListParse(s, &out);
+	}
+
+	return out;
+}
 
 /************************************************************************/
 /* various conversion functions					*/
@@ -954,6 +992,7 @@ static const char * const query_attrConsts[] = {
 	"EDG_WLL_QUERY_ATTR_JDL_ATTR",
 	"EDG_WLL_QUERY_ATTR_STATEENTERTIME",
 	"EDG_WLL_QUERY_ATTR_LASTUPDATETIME",
+        "EDG_WLL_QUERY_ATTR_JOB_TYPE",
         "EDG_WLL_QUERY_ATTR__LAST",
 };
 
